<?php declare(strict_types = 1);

namespace PQAD\Providers\Dashboard;

use PQAD\Entities\Pqad_Settings as Settings_Entity;
use PQAD\Services\Dashboard\Pqad_Settings as Service;
use PQAD\Services\Utils\Pqad_Token as Token;
use WPSteak\Providers\AbstractHookProvider;

class Pqad_Options extends AbstractHookProvider {

	/**
	 * Settings.
	 *
	 * @var Service
	 */
    protected $service;
    /**
	 * Token.
	 *
	 * @var Token
	 */
	protected $token;

	public function __construct( Service $service, Token $token ) {
        $this->service          = $service;
        $this->token            = $token;
		$this->get_client_key   = get_option( 'wc_settings_ame_digital_client_id' );
		$this->get_client_token = get_option( 'wc_settings_ame_digital_client_secret' );
	}

	public function register_hooks() {
		$this->add_filter( 'plugin_action_links_wc-ame-digital/wc-ame-digital.php', 'plugin_links' );
		$this->add_filter( 'plugin_row_meta', 'support_links', 10, 4 );
		$this->add_filter( 'cron_schedules', 'pqad_add_cron_interval' );
		$this->add_action( 'admin_init', 'pqad_register_schedule' );
		$this->add_action( 'pqad_every_twenty_days', 'pqad_renew_ame_token' );
	}
	/**
	 * Add link settings page
	 *
	 * @since 1.0
	 * @param Array $links
	 * @return Array
	 */
	public function plugin_links( $links )
	{
		$links_settings = array( sprintf(
            '<a href="%s">%s</a>',
			'admin.php?page=wc-settings&tab=ame_digital',
            __( 'Configurações', 'wc-ame-digital' )
		) );

		$qrcode_settings = array( sprintf(
            '<a href="%s">%s</a>',
			'admin.php?page=wc-settings&tab=checkout&section=ame-digital',
            __( 'Pagamento Ame', 'wc-ame-digital' )
		) );

		return array_merge( $links_settings, $qrcode_settings, $links );
	}
	/**
	 * Add support link page
	 *
	 * @since 1.0
	 * @param Array $links
	 * @return Array
	 */
	public function support_links( $links_array, $plugin_file_name, $plugin_data, $status ) {

		if ( $plugin_file_name === 'wc-ame-digital/wc-ame-digital.php' ) {
			$links_array[] = '<a href="https://amedigital.github.io/">'.__( 'Documentação da API', 'wc-ame-digital' ).'</a>';
			$links_array[] = '<a href="https://apiki.com/parceiros/ame/">'.__( 'Suporte da Apiki', 'wc-ame-digital' ).'</a>';
		}

		return $links_array;
	}
	/**
	 * Add cron interval
	 *
	 * @since 1.1.8
	 * @param Array $links
	 * @return Array
	 */
	public function pqad_add_cron_interval( $schedules ) {
		//add a 'every_twenty_days' schedule to the existing set
		$schedules['every_twenty_days'] = array(
			'interval' => 1728000,
			'display'  => esc_html__( 'Renovação do token a cada 20 dias.' )
		);

		return $schedules;
	}
	/**
	 * Register cron schedule
	 *
	 * @since 1.1.8
	 * @param Array $links
	 * @return Array
	 */
	public function pqad_register_schedule() {

		if ( ! wp_next_scheduled( 'pqad_every_twenty_days' ) ) {
			wp_schedule_event( time(), 'every_twenty_days', 'pqad_every_twenty_days' );
		}
	}
	/**
	 * Renew ame token
	 *
	 * @since 1.1.8
	 * @param Array $links
	 * @return Array
	 */
	public function pqad_renew_ame_token() {
		if ( $this->get_client_key && $this->get_client_token ) {
			$this->token->update_token();
			update_option( '_pqad_ame_access_token', 'updated' );
		}
	}
}
