<?php declare(strict_types = 1);

namespace PQAD\Providers\Dashboard;

use PQAD\Services\Dashboard\Pqad_Settings as Service;
use PQAD\Services\Utils\Pqad_Token as Token;
use PQAD\Entities\Pqad_Settings as Settings_Entity;
use PQAD\Entities\Pqad_Api as Api_Entity;
use WPSteak\Providers\AbstractHookProvider;

class Pqad_Settings extends AbstractHookProvider {

	/**
	 * Settings.
	 *
	 * @var Service
	 */
    protected $service;
    /**
	 * Token.
	 *
	 * @var Token
	 */
	protected $token;

	public function __construct( Service $service, Token $token ) {
        $this->service          = $service;
        $this->token            = $token;
		$this->get_client_key   = get_option( 'wc_settings_ame_digital_client_id' );
		$this->get_client_token = get_option( 'wc_settings_ame_digital_client_secret' );
	}

	public function register_hooks() {
		$this->add_filter( 'woocommerce_settings_tabs_array', 'add_settings_tab', 50 );
        $this->add_action( 'woocommerce_settings_tabs_' . Settings_Entity::WAD_NAME, 'tab_content' );
		$this->add_action( 'woocommerce_update_options_' . Settings_Entity::WAD_NAME, 'update_settings' );
		$this->add_action( 'admin_init', 'update_ame_access_token' );
    }
	/**
     * Add a settings tab to the settings WooCommerce
     *
     * @param array $settings_tabs
     *
     * @since  1.0.0
     * @access public
     *
     * @return array
     */
    public function add_settings_tab( $settings_tabs ) {
		$settings_tabs[Settings_Entity::WAD_NAME] = __( 'Ame', 'wc-ame-digital' );
        return $settings_tabs;
    }
    /**
     * Output the tab content
     *
     * @since  1.0.0
     * @access public
     *
     */
    public function tab_content() {
        woocommerce_admin_fields( $this->service->get_fields() );
    }
    /**
     * Update the settings
     *
     * @since  1.0.0
     * @access public
     */
    public function update_settings() {

		woocommerce_update_options( $this->service->get_fields() );

		$this->token->create_token();
		update_option( '_pqad_ame_access_token', 'updated' );
	}
 	/**
     * Update ame access token
     *
     * @since  1.1.8
     * @access public
     */
	public function update_ame_access_token() {
		$access_token = get_option( '_pqad_ame_access_token' );

		if ( $this->get_client_key && $this->get_client_token ) {
			if ( !$access_token ) {
				$this->token->update_token();
				update_option( '_pqad_ame_access_token', 'updated' );
			}
		}
	}
}
