<?php declare(strict_types = 1);

namespace PQAD\Providers\Woocommerce;

use PQAD\Entities\Pqad_Settings as Settings_Entity;
use WPSteak\Providers\AbstractHookProvider;

use stdClass;

class Pqad_Checkouts extends AbstractHookProvider {

    public function __construct() {
        $this->welcome_learn_more = get_site_option( 'welcome_learn_more' );
		$this->options            = get_option( 'woocommerce_ame-digital_settings' );
	}

	public function register_hooks() {
        $this->add_action( 'woocommerce_receipt_ame-digital', 'receipt_page', 10  );
        $this->add_action( 'wp_ajax_order_status', 'get_order_status' );
		$this->add_action( 'wp_ajax_nopriv_order_status', 'get_order_status' );
		$this->add_action( 'wp_ajax_order_key', 'get_order_key' );
		$this->add_action( 'wp_ajax_nopriv_order_key', 'get_order_key' );
		$this->add_filter( 'woocommerce_billing_fields', 'pqad_billing_checkout_field' );
		$this->add_filter( 'woocommerce_shipping_fields', 'pqad_shipping_checkout_field' );
		$this->add_action( 'woocommerce_admin_order_data_after_billing_address', 'pqad_data_after_billing_address' );
		$this->add_action( 'woocommerce_admin_order_data_after_shipping_address', 'pqad_data_after_shipping_address' );
		$this->add_action( 'woocommerce_checkout_update_order_meta', 'pqad_checkout_update_order_meta' );
    }

    public function receipt_page( $order_id ) {
        $qrcode_url         = get_post_meta( $order_id, '_wad_qrcode_link', true );
        $api_status         = get_post_meta( $order_id, '_wad_api_order_status', true );
        $order_status       = 'hold';
        $order              = wc_get_order( $order_id );
        $order_received_url = wc_get_endpoint_url( 'order-received', $order->get_id(), wc_get_checkout_url() );
        $order_received_url = add_query_arg( 'key', $order->get_order_key(), $order_received_url );
		$title              = $this->options['checkout_title'];
		$amount             = wc_price( $order->get_total() );
		$is_cashback        = '';
		$get_cashback       = get_post_meta( $order_id, '_wad_api_order_cashbackamount', true );
		$logo               = $this->plugin->get_url( 'resources/images/ame-pay.png' );

		if ( $get_cashback > 0 ) {
			$is_cashback  = 'yes';
			$cashback     = number_format( ( $get_cashback/100 ), 2, ",","." );
		}

        include $this->plugin->get_path( 'views/checkout/order-pay.php' );
    }

    public function get_order_status() {
        $callback         = new stdClass();
		$order_id         = Settings_Entity::get( 'order-id', FILTER_SANITIZE_NUMBER_INT );
		$order            = wc_get_order( $order_id );
		$order_status     = get_post_meta( $order_id, '_wad_api_order_status', true );
		$callback->status = false;

        if ( $order_status !== 'hold' ) {
			$callback->status = true;
        }

        echo json_encode( $callback );
        exit;
	}

	public function get_order_key() {
        $callback           = new stdClass();
		$order_id           = Settings_Entity::get( 'order-id', FILTER_SANITIZE_NUMBER_INT );
		$order              = wc_get_order( $order_id );
		$callback->orderKey =  $order->get_order_key();

        echo json_encode( $callback );
        exit;
	}

	public function pqad_billing_checkout_field( $fields ) {
		$custom_fields = array();

		$custom_fields['billing_number'] = array(
			'label'       => __( 'Número', 'wc-ame-digital' ),
			'placeholder' => __( 'Número', 'wc-ame-digital' ),
			'class'       => array( 'form-row-first', 'address-field' ),
			'clear'       => true,
			'required'    => true,
			'priority'    => 55,
		);

		$custom_fields['billing_neighborhood'] = array(
			'label'       => __( 'Bairro', 'wc-ame-digital' ),
			'placeholder' => __( 'Bairro', 'wc-ame-digital' ),
			'class'       => array( 'form-row-last', 'address-field' ),
			'clear'       => true,
			'required'    => true,
			'priority'    => 56,
		);

		$fields = wp_parse_args( $custom_fields, $fields );

		return apply_filters( 'wc_ame_digital_billing_checkout_fields', $fields );
	}

	public function pqad_shipping_checkout_field( $fields ) {
		$custom_fields = array();

		$custom_fields['shipping_number'] = array(
			'label'       => __( 'Número', 'wc-ame-digital' ),
			'placeholder' => __( 'Número', 'wc-ame-digital' ),
			'class'       => array( 'form-row-first', 'address-field' ),
			'clear'       => true,
			'required'    => true,
			'priority'    => 55,
		);

		$custom_fields['shipping_neighborhood'] = array(
			'label'       => __( 'Bairro', 'wc-ame-digital' ),
			'placeholder' => __( 'Bairro', 'wc-ame-digital' ),
			'class'       => array( 'form-row-last', 'address-field' ),
			'clear'       => true,
			'required'    => true,
			'priority'    => 56,
		);

		$fields = wp_parse_args( $custom_fields, $fields );

		return apply_filters( 'wc_ame_digital_shipping_checkout_fields', $fields );
	}

	public function pqad_data_after_billing_address( $order ) {
		$order_id     = $order->get_id();
		$number       = get_post_meta( $order_id, '_billing_number', true );
		$neighborhood = get_post_meta( $order_id, '_billing_neighborhood', true );

		if ( $number ) {
			echo '<p>'.__('Número da Casa: ', 'wc-ame-digital').$number.'</p>';
		}

		if ( $neighborhood ) {
			echo '<p>'.__('Bairro: ', 'wc-ame-digital').$neighborhood.'</p>';
		}
	}

	public function pqad_data_after_shipping_address( $order ) {
		$order_id     = $order->get_id();
		$number       = get_post_meta( $order_id, '_shipping_number', true );
		$neighborhood = get_post_meta( $order_id, '_shipping_neighborhood', true );

		if ( $number ) {
			echo '<p>'.__('Número da Casa: ', 'wc-ame-digital').$number.'</p>';
		}

		if ( $neighborhood ) {
			echo '<p>'.__('Bairro: ', 'wc-ame-digital').$neighborhood.'</p>';
		}
	}

	public function pqad_checkout_update_order_meta( $order_id ) {
		if ( ! empty( $_POST['billing_number'] ) ) {
			update_post_meta( $order_id, '_billing_number', sanitize_text_field( $_POST['billing_number'] ) );
		}
		if ( ! empty( $_POST['billing_neighborhood'] ) ) {
			update_post_meta( $order_id, '_billing_neighborhood', sanitize_text_field( $_POST['billing_neighborhood'] ) );
		}
		if ( ! empty( $_POST['shipping_number'] ) ) {
			update_post_meta( $order_id, '_shipping_number', sanitize_text_field( $_POST['shipping_number'] ) );
		}
		if ( ! empty( $_POST['shipping_neighborhood'] ) ) {
			update_post_meta( $order_id, '_shipping_neighborhood', sanitize_text_field( $_POST['shipping_neighborhood'] ) );
		}
	}
}
