<?php
/**
 * QrCode
 *
 * @package PQAD
 */

declare(strict_types=1);

namespace PQAD\Repositories;

use PQAD\Entities\Pqad_Api as Api_Entity;
use PQAD\Entities\Pqad_Logs as Logs_Entity;

/**
 * QrCode class.
 */
class Pqad_QrCode {
	/**
     * Register header token
     *
     * @since  1.0.0
     * @access public
     */
    public static function get_header_token() {
        $token = get_option( 'wc_settings_ame_digital_access_token' );

        if ( empty( $token ) ) {
            return;
        }

        if ( $token ) {
            $token = base64_decode( get_option( 'wc_settings_ame_digital_access_token' ) );
        }

		return $token;
	}
    /**
     * Register header route
     *
     * @since  1.0.0
     * @access public
     */
    public static function get_header() {
		return array(
			'content-type'   => 'application/json',
			'content-length' => 0,
            'authorization'  => 'Bearer '.self::get_header_token()
        );
	}

	/**
     * Register header refund route
     *
     * @since  1.0.0
     * @access public
     */
    public static function get_header_refund() {
		return array(
			'content-type'   => 'application/json',
            'authorization'  => 'Bearer '.self::get_header_token()
        );
	}

	public static function get_remote_capture( $id ) {
		$environment = get_option( 'wc_settings_ame_digital_environment' );
		$capture_url = Api_Entity::HOMOLOG_URL;

		if ( $environment === 'production' ) {
			$capture_url = Api_Entity::PROD_URL;
		}

		$url  = $capture_url . '/api/wallet/user/payments/'.$id.'/capture';
		$args = array(
			'headers' => self::get_header(),
			'method'  => 'PUT',
			'timeout' => 200,
		);

		$response = wp_remote_request( $url, $args );

		if ( is_wp_error( $response ) ) {
			$error_string = $response->get_error_message();
			Logs_Entity::capture_order_error( 'AME DIGITAL CAPTURE ERROR', $response );
		}

        return $response;
    }

    public static function get_remote_cancel( $id ) {
		$environment = get_option( 'wc_settings_ame_digital_environment' );
		$cancel_url  = Api_Entity::HOMOLOG_URL;

		if ( $environment === 'production' ) {
			$cancel_url = Api_Entity::PROD_URL;
		}

		$response = wp_remote_request(
			$cancel_url . '/api/wallet/user/payments/'.$id.'/cancel',
			array(
				'headers' => self::get_header(),
				'method'  => 'PUT',
				'timeout' => 200,
			)
		);

		if ( is_wp_error( $response ) ) {
			$error_string = $response->get_error_message();
			Logs_Entity::cancel_order_error( 'AME DIGITAL CANCEL ERROR', $response );
		}

        return $response;
    }

    public static function get_remote_refund( $id, $amount, $refund_id ) {
		$environment = get_option( 'wc_settings_ame_digital_environment' );
		$refund_url   = Api_Entity::HOMOLOG_URL;

		if ( $environment === 'production' ) {
			$refund_url   = Api_Entity::PROD_URL;
		}

		$response = wp_remote_request(
			$refund_url . '/api/payments/'.$id.'/refunds/WOO-AME-'.$refund_id.'-'.$id,
			array(
				'headers' => self::get_header_refund(),
				'method'  => 'PUT',
				'body'    => wp_json_encode( array( 'amount' => $amount ) ),
				'timeout' => 200,
			)
		);

		if ( is_wp_error( $response ) ) {
			$error_string = $response->get_error_message();
			Logs_Entity::refund_order_error( 'AME DIGITAL REFUND ERROR', $response );
		}

    	return $response;
  }

}
