<?php
/**
 * Dashboard Settings
 *
 * @package PQAD
 */

declare(strict_types=1);

namespace PQAD\Services\Dashboard;

use PQAD\Entities\Pqad_Settings as Settings_Entity;

class Pqad_Settings {

    /**
     * Get the setting fields
     *
     * @since  1.0.0
     * @access private
     *
     * @return array $setting_fields
     */
    public function get_fields() {

		//Render admin message
		Settings_Entity::render_admin_message();

        $setting_fields = array(
            'section_title' => array(
                'name' => __( 'Ame Digital', 'wc-ame-digital' ),
                'type' => 'title',
                'desc' => '',
                'id'   => 'wc_settings_ame_digital_title'
            ),
            'section_environment' => array(
                'name'     => __( 'Ambiente', 'wc-ame-digital' ),
				'type'     => 'select',
				'desc_tip' => true,
                'desc'     => __( 'Selecione o ambiente de sandbox ou produção. Para o ambiente de sandbox será necessário solicitar a AME o APP de teste.', 'wc-ame-digital' ),
				'id'       => 'wc_settings_ame_digital_environment',
                'options'          => array(
                    'sandbox'    => __( 'Sandbox', 'wc-ame-digital' ),
                    'production' => __( 'Production', 'wc-ame-digital' ),
                ),
            ),
            'section_client_id' => array(
                'name'              => __( 'Application Key', 'wc-ame-digital' ),
				'type'              => 'text',
				'desc_tip'          => true,
                'desc'              => __( 'Adicione a Application Key gerado na sua conta AME no menu Integração.', 'wc-ame-digital' ),
                'id'                => 'wc_settings_ame_digital_client_id',
                'custom_attributes' => array( 'required' => 'required' )
            ),
            'section_client_secret' => array(
                'name'              => __( 'Application Token', 'wc-ame-digital' ),
				'type'              => 'text',
				'desc_tip'          => true,
                'desc'              => __( 'Adicione o Application Token gerado na sua conta AME no menu Integração.', 'wc-ame-digital' ),
                'id'                => 'wc_settings_ame_digital_client_secret',
                'custom_attributes' => array( 'required' => 'required' )
			),
            'section_end'   => array(
                'type' => 'sectionend',
                'id'   => 'wc_settings_ame_digital_section_end'
            )
        );

        return apply_filters( 'wc_settings_tab_ame_digital', $setting_fields );
    }
}
