<?php
/**
 * Gateway QR Code
 *
 * @package PQAD
 */

declare(strict_types=1);

namespace PQAD\Services\Gateways;

use WC_Payment_Gateway;

use PQAD\Entities\Pqad_Api as Api_Entity;
use PQAD\Entities\Pqad_Security as Security_Entity;
use PQAD\Entities\Pqad_Settings as Settings_Entity;
use PQAD\Entities\Pqad_Logs as Logs_Entity;

class Pqad_QrCode extends WC_Payment_Gateway {

    public function __construct() {
        $this->id                 = 'ame-digital';
        $this->icon               = Settings_Entity::plugins_url( '/resources/images/ame-logo.png' );
        $this->has_fields         = true;
        $this->method_title       = __( 'Ame', 'wc-ame-digital' );
        $this->method_description = __( 'Método de Pagamento Ame Digital', 'wc-ame-digital' );
		$this->supports           = array( 'products' );
		$this->token              = get_option( 'wc_settings_ame_digital_access_token' );

		if ( !$this->token ) {
			return $this->not_form_fields();
		}

        $this->init_form_fields();
        $this->init_settings();

        $this->title          = $this->get_option( 'title' );
        $this->description    = $this->get_option( 'description' );
		$this->enabled        = $this->get_option( 'enabled' );
        $this->checkout_title = $this->get_option( 'checkout_title' );
		$this->enabled_logs   = $this->get_option( 'enabled_logs' );
		$this->environment    = get_option( 'wc_settings_ame_digital_environment' );
        $this->sandbox        = 'sandbox' === get_option( 'wc_settings_ame_digital_environment' );
		$this->logs           = 'yes' === $this->get_option( 'enabled_logs' );
		$this->woo_logs       = admin_url( 'page=wc-status&tab=logs' );

        if ( $this->token ) {
            $this->token = base64_decode( get_option( 'wc_settings_ame_digital_access_token' ) );
        }

        if ( is_admin() ) {
			add_action( 'woocommerce_update_options_payment_gateways_' . $this->id, array( $this, 'process_admin_options' ) );
        }

        //add_action( 'woocommerce_api_'. Api::CALLBACK_URL, array( $this, 'payment_callback' ) );
	}

	/**
     * Plugin options, not fields
     */
    public function not_form_fields() {

		$this->form_fields = array(
			'customize_button' => array(
				'title'             => __( 'Gerar Token', 'wc-ame-digital' ),
				'type'              => 'button',
				'custom_attributes' => array(
					'onclick' => "location.href='admin.php?page=wc-settings&tab=ame_digital'",
				),
				'description'       => __( 'Para ativar a forma de pagamento, você precisa gerar o token primeiro. Clique no botão', 'wc-ame-digital' ),
				'desc_tip'          => false,
			)
		);
	}

	public function generate_button_html( $key, $data ) {
		$field    = $this->plugin_id . $this->id . '_' . $key;
		$defaults = array(
			'class'             => 'button-secondary',
			'css'               => '',
			'custom_attributes' => array(),
			'desc_tip'          => false,
			'description'       => '',
			'title'             => '',
		);

		$data = wp_parse_args( $data, $defaults );

		ob_start();
		?>
		<tr valign="top">
			<th scope="row" class="titledesc">
				<label for="<?php echo esc_attr( $field ); ?>"><?php echo wp_kses_post( $data['title'] ); ?></label>
				<?php echo $this->get_tooltip_html( $data ); ?>
			</th>
			<td class="forminp">
				<fieldset>
					<legend class="screen-reader-text"><span><?php echo wp_kses_post( $data['title'] ); ?></span></legend>
					<button class="<?php echo esc_attr( $data['class'] ); ?>" type="button" name="<?php echo esc_attr( $field ); ?>" id="<?php echo esc_attr( $field ); ?>" style="<?php echo esc_attr( $data['css'] ); ?>" <?php echo $this->get_custom_attribute_html( $data ); ?>><?php echo wp_kses_post( $data['title'] ); ?></button>
					<?php echo $this->get_description_html( $data ); ?>
				</fieldset>
			</td>
		</tr>
		<?php
		return ob_get_clean();
	}
   /**
     * Plugin options, we deal with it in Step 3 too
     */
    public function init_form_fields() {

        $this->form_fields = array(
            'enabled' => array(
                'title'       =>  __( 'Habilitar', 'wc-ame-digital' ),
                'label'       => __( 'Habilitar pagamento', 'wc-ame-digital' ),
                'type'        => 'checkbox',
                'description' => '',
                'default'     => 'no'
            ),
            'title' => array(
                'title'       => __( 'Título', 'wc-ame-digital' ),
                'type'        => 'text',
                'description' => __( 'Altera o título que o usuário visualiza na página de checkout.', 'wc-ame-digital' ),
                'default'     => __( 'Ame Digital', 'wc-ame-digital' ),
                'desc_tip'    => true,
            ),
            'description' => array(
                'title'       => __( 'Descrição', 'wc-ame-digital' ),
				'type'        => 'textarea',
				'css'         => 'width: 400px;',
                'description' => __( 'Altera a descrição que o usuário visualiza na página de checkout.', 'wc-ame-digital' ),
                'default'     => __( 'Pague com seu celular através do nosso método de pagamento Ame.', 'wc-ame-digital' ),
			),
            'checkout_title' => array(
                'title'       => __( 'Título do Pagamento', 'wc-ame-digital' ),
                'type'        => 'text',
                'description' => __( 'Alter o título que o usuário visualiza durante o pagamento do pedido.', 'wc-ame-digital' ),
                'default'     => __( 'Pagar com Ame', 'wc-ame-digital' ),
			),
			'order_status' => array(
                'title'       => __( 'Status Pedido', 'wc-ame-digital' ),
				'type'        => 'select',
				'options'     => array(
					'pqad_processing' => 'Processando',
					'pqad_completed'  => 'Concluído'
				),
                'description' => __( 'Altera o pedido no woocommerce quando está pago na AME.', 'wc-ame-digital' ),
                'default'     => 'pqad_processing',
            ),
            'enabled_logs' => array(
                'title'       =>  __( 'Logs', 'wc-ame-digital' ),
                'label'       => __( 'Habilita os logs. Para visualizar: WooCommerce>Status>Logs', 'wc-ame-digital' ),
                'type'        => 'checkbox',
                'description' => '',
                'default'     => 'no'
            ),
        );
	}
	/**
     * Plugin admin options,
     */
	public function admin_options() {

		$environment = __( 'MODO PRODUÇÃO HABILITADO!' );

		if ( $this->sandbox ) {
			$environment = __( 'MODO SANDBOX HABILITADO!' );
		}

		//Render admin message
		Settings_Entity::render_admin_message();

		printf(
			'<h3>%s</h3>
			<p>%s</p>
			<h4>%s</h4>',
			__( 'AME Digital' ),
			__( 'Método de pagamento via QRCode Ame Digital.' ),
			$environment
		);
	?>

	<table class="form-table">
		<?php $this->generate_settings_html(); ?>
	</table>
<?php
	}

    public function payment_fields() {

        if ( $this->description ) {

            if ( $this->sandbox ) {
				$this->description .= '<br>';
				$this->description .= __( '<strong>MODO SANDBOX HABILITADO!</strong>', 'wc-ame-digital' );
               $this->description   = trim( $this->description );
            }

            echo wpautop( wp_kses_post( $this->description ) );
        }

		printf('<fieldset id="wc-%s-form"
		class="wc-woo-ame-digital wc-payment-form"
		style="background:transparent;">
		<div class="clear"></div></fieldset>', esc_attr( $this->id ) );

    }

    public function get_header()
	{
		return array(
            'content-type'  => 'application/json',
            'authorization' => 'Bearer '.$this->token
        );
	}

    public function process_payment( $order_id ) {

        global $woocommerce;

        $order          = wc_get_order( $order_id );
        $items          = $order->get_items();
        $total_order    = str_replace( '.', '', $order->get_total() );
        $total          = str_pad( $total_order, 4, '0', STR_PAD_LEFT );
		$args           = [];
		$order_url      = Api_Entity::HOMOLOG_URL;
		$shipping       = $this->pqad_get_shipping_address( $order_id );
		$billing        = $this->pqad_get_billing_address( $order_id );
		$shipping_total = $order->get_shipping_total();
		$replace        = str_replace( '.', '', $shipping_total );
		$shipping_value = str_pad( $replace, 4, '0', STR_PAD_LEFT );
		//$cashback_total = Settings_Entity::cashback_amount( $this->cashback_amount, $order->get_total() );

		if ( empty( $shipping ) ) {
			$shipping = $billing;
		}

		if ( $this->environment === 'production' ) {
			$order_url = Api_Entity::PROD_URL;
		}

        foreach ( $items as $item ) {
            $name           = $item->get_name();
            $quantity       = $item->get_quantity();
            $subtotal_order = number_format( (float)$item->get_subtotal(), 2, '', '.' );
            $subtotal       = str_pad( $subtotal_order, 4, '0', STR_PAD_LEFT );

            $args[] = array(
                'description' => $name,
                'quantity'    => $quantity,
                'amount'      => (int)$subtotal
            );
        }

        $body  = array(
            'title'       => 'Order #' . $order_id,
            'description' => $this->title,
            'amount'      => (int)$total,
            'type'        => 'PAYMENT',
            'attributes'  => array(
                //'cashbackAmountValue'           => $cashback_total, //cashback %
                'transactionChangedCallbackUrl' => rest_url( Api_Entity::REST_ROUTE.'/callback' ),
                'items'                         => $args,
				'customPayload'                 => array(
					'ShippingValue'   => $shipping_value,
					'shippingAddress' => array(
						'shippingAddress' => $shipping
					),
					'billingAddress'  => array(
						'billingAddress' => $billing
					),
					'isFrom' => 'Woocommerce'
				),
				'paymentOnce'     => TRUE,
				'riskHubProvider' => 'SYNC',
				'origin'          => 'ECOMMERCE',
			),
		);

        $response = wp_remote_post(
			$order_url . '/api/orders',
			array(
                'headers' => $this->get_header(),
                'body'    => json_encode( $body ),
				'timeout' => 200,
			)
        );

		$response_body = wp_remote_retrieve_body( $response );
		$response      = json_decode( $response_body );
		$cashback_api  = 0;

		if ( $response ) {
			if ( $response->attributes->cashbackAmountValue ) {
				$cashback_api = $response->attributes->cashbackAmountValue;
			}
		}

        update_post_meta( $order_id, '_wad_qrcode_link', $response->qrCodeLink );
        update_post_meta( $order_id, '_wad_api_order_id', $response->id );
		update_post_meta( $order_id, '_wad_api_order_status', 'hold' );
		update_post_meta( $order_id, '_wad_api_order_cashbackamount', $cashback_api );

        if (  $this->logs ) {
            Logs_Entity::send_order( 'AME DIGITAL ORDER ID', $order_id );
			Logs_Entity::send_order( 'AME DIGITAL ORDER', $body );

			Logs_Entity::order_response( 'AME DIGITAL ORDER ID', $order_id );
            Logs_Entity::order_response( 'AME DIGITAL RESPONSE', $response );
        }

        $order->add_order_note(  __( 'Ame: Aguardando pagamento.', 'wc-ame-digital') );
        wc_reduce_stock_levels( $order_id );
        WC()->cart->empty_cart();

        return array(
            'result' => 'success',
            'redirect' => $order->get_checkout_payment_url( true )
        );
	}

	public function pqad_get_shipping_address( $order_id ) {
		$order        = wc_get_order( $order_id );
		$number       = get_post_meta( $order_id, '_shipping_number', true );
		$neighborhood = get_post_meta( $order_id, '_shipping_neighborhood', true );

		$fields = array(
			'country'      => $order->get_shipping_country(),
			'number'       => $number,
			'city'         => $order->get_shipping_city(),
			'street'       => $order->get_shipping_address_1(),
			'postalCode'   => $order->get_shipping_postcode(),
			'neighborhood' => $neighborhood,
			'state'        => $order->get_shipping_state()
		);

		return $fields;
	}

	public function pqad_get_billing_address( $order_id ) {
		$order        = wc_get_order( $order_id );
		$number       = get_post_meta( $order_id, '_billing_number', true );
		$neighborhood = get_post_meta( $order_id, '_billing_neighborhood', true );

		$fields = array(
			'country'      => $order->get_billing_country(),
			'number'       => $number,
			'city'         => $order->get_billing_city(),
			'street'       => $order->get_billing_address_1(),
			'postalCode'   => $order->get_billing_postcode(),
			'neighborhood' => $neighborhood,
			'state'        => $order->get_billing_state()
		);

		return $fields;
	}
}
