<?php
/**
 * Utils Token
 *
 * @package PQAD
 */

declare(strict_types=1);

namespace PQAD\Services\Utils;

use PQAD\Entities\Pqad_Api as Api_Entity;
use PQAD\Entities\Pqad_Security as Security_Entity;
use PQAD\Entities\Pqad_Settings as Settings_Entity;
use PQAD\Entities\Pqad_Logs as Logs_Entity;

class Pqad_Token {

    private $client_id;
    private $client_secret;

    public function get_header()
	{
        // $this->client_id     = get_option( 'wc_settings_ame_digital_client_id' );
		// $this->client_secret = get_option( 'wc_settings_ame_digital_client_secret' );
		$this->client_id     = Settings_Entity::post( 'wc_settings_ame_digital_client_id', FILTER_SANITIZE_STRING );
        $this->client_secret = Settings_Entity::post( 'wc_settings_ame_digital_client_secret', FILTER_SANITIZE_STRING );
		$token_id            = base64_encode( $this->client_id.':'.$this->client_secret );

		return array(
            'content-type'  => 'application/x-www-form-urlencoded',
            'Authorization' => 'Basic ' . $token_id
        );
	}

	//Create Access Token
    public function create_token() {
		$environment = Settings_Entity::post( 'wc_settings_ame_digital_environment', FILTER_SANITIZE_STRING );
		$token_url   = Api_Entity::HOMOLOG_URL;

		if ( $environment === 'production' ) {
			$token_url   = Api_Entity::PROD_URL;
		}

        $args =	array(
			'headers' => $this->get_header(),
			'body'    => 'grant_type=client_credentials',
			'timeout' => 20,
		);

		$response = wp_remote_post( $token_url . '/api/auth/oauth/token', $args );

		if ( is_wp_error( $response ) ) {
			ob_start();
			printf('<div id="message" class="error"><p>%s</p></div>',
			__( 'Ame Digital: Não foi possível gerar seu token de produção, entre em contato com a AME! Tente mais tarde.', 'wc-ame-digital' ) );

			delete_option( 'wc_settings_ame_digital_access_token' );
			delete_option( 'wc_settings_ame_digital_token_expires_in' );
		}

		$code      = wp_remote_retrieve_response_code( $response );
		$body      = wp_remote_retrieve_body( $response );
		$response  = json_decode( $body );

		if ( in_array( $code, [200, 201] ) ) {
			//$access_token = Security_Entity::encrypt( $response->access_token );
			$access_token = base64_encode( $response->access_token );

			update_option( 'wc_settings_ame_digital_access_token', $access_token );
			update_option( 'wc_settings_ame_digital_token_expires_in', $response->expires_in );

			ob_start();
			printf('<div id="message" class="updated"><p>%s</p></div>', __( 'Ame Digital: Token criado com sucesso!', 'wc-ame-digital' ) );

		}

		if ( isset( $response->error_description ) ) {
			Logs_Entity::token_callback_error( 'AME DIGITAL URL', $token_url . '/api/auth/oauth/token' );
			Logs_Entity::token_callback_error( 'AME DIGITAL ARGUMENTOS', json_encode( $args ) );

			ob_start();
			printf('<div id="message" class="error"><p>%s %s %s</p></div>',
			__( 'Ame Digital:', 'wc-ame-digital' ),
			$response->error_description,
			__( 'Log gerado!', 'wc-ame-digital' ) );
		}
	}

	//Update Access Token
	public function update_token() {
		$environment = Settings_Entity::post( 'wc_settings_ame_digital_environment', FILTER_SANITIZE_STRING );
		$token_url   = Api_Entity::HOMOLOG_URL;

		if ( $environment === 'production' ) {
			$token_url   = Api_Entity::PROD_URL;
		}

        $args =	array(
			'headers' => $this->get_header(),
			'body'    => 'grant_type=client_credentials',
			'timeout' => 20,
		);

		$response = wp_remote_post( $token_url . '/api/auth/oauth/token', $args );

		if ( is_wp_error( $response ) ) {
			delete_option( 'wc_settings_ame_digital_access_token' );
			delete_option( 'wc_settings_ame_digital_token_expires_in' );
		}

		$code      = wp_remote_retrieve_response_code( $response );
		$body      = wp_remote_retrieve_body( $response );
		$response  = json_decode( $body );

		if ( in_array( $code, [200, 201] ) ) {
			//$access_token = Security_Entity::encrypt( $response->access_token );
			$access_token = base64_encode( $response->access_token );

			update_option( 'wc_settings_ame_digital_access_token', $access_token );
			update_option( 'wc_settings_ame_digital_token_expires_in', $response->expires_in );
		}

		if ( isset( $response->error_description ) ) {
			Logs_Entity::token_callback_error( 'AME DIGITAL URL', $token_url . '/api/auth/oauth/token' );
			Logs_Entity::token_callback_error( 'AME DIGITAL ARGUMENTOS', json_encode( $args ) );
		}
    }
}
